select
    year_month,
    region,
    sum(total_sales) as total_sales

from { csv("data/sales.csv", ";") }

group by
    year_month,
    region